==> simgrid_3.9~rc1.orig.tar.gz: SimGrid-3.9/doc/html/use.js <==
var use =
[
    [ "Using MSG", "use.html#using_msg", [
      [ "Basic examples and features", "use.html#MSG_ex_basics", [
        [ "Asynchronous communications", "use.html#MSG_ex_asynchronous_communications", [
          [ "Code of the application", "use.html#MSG_ext_icomms_code", null ],
          [ "Preliminary declarations", "use.html#MSG_ext_icomms_preliminary", null ],
          [ "Sender function", "use.html#MSG_ext_icomms_Sender", null ],
          [ "Receiver function", "use.html#MSG_ext_icomms_Receiver", null ],
          [ "Simulation core", "use.html#MSG_ext_icomms_core", null ],
          [ "Main function", "use.html#MSG_ext_icomms_Main", null ],
          [ "Waitall function for sender", "use.html#MSG_ext_icomms_fct_Waitall", null ],
          [ "Waitany function", "use.html#MSG_ext_icomms_fct_Waitany", null ],
          [ "From a sender", "use.html#MSG_ext_icomms_fct_Waitany_sender", null ],
          [ "From a receiver", "use.html#MSG_ext_icomms_fct_Waitany_receiver", null ]
        ] ],
        [ "Basic Master/Slaves", "use.html#MSG_ex_master_slave", [
          [ "Table of contents:", "use.html#MSG_ex_ms_TOC", null ],
          [ "Preliminary declarations", "use.html#MSG_ext_ms_preliminary", null ],
          [ "Master code", "use.html#MSG_ext_ms_master", null ],
          [ "Slave code", "use.html#MSG_ext_ms_slave", null ],
          [ "Forwarder code", "use.html#MSG_ext_ms_forwarder", null ],
          [ "Simulation core", "use.html#MSG_ext_ms_core", null ],
          [ "Main() function", "use.html#MSG_ext_ms_main", null ]
        ] ],
        [ "Helping files", "use.html#MSG_ext_ms_helping", [
          [ "Example of application file", "use.html#MSG_ext_ms_application", null ],
          [ "Example of platform file", "use.html#MSG_ext_ms_platform", null ]
        ] ]
      ] ]
    ] ],
    [ "Using SMPI", "use.html#using_smpi", null ],
    [ "Using Model Checking", "use.html#using_MC", null ],
    [ "Using Trace", "use.html#using_trace", null ],
    [ "Using SimDag", "use.html#using_simdag", null ],
    [ "Using SIMIX", "use.html#using_simix", null ],
    [ "Platform Description", "platform.html", [
      [ "Some words about XML and DTD", "platform.html#pf_overview", null ],
      [ "Basic concepts", "platform.html#pf_basics", null ],
      [ "Describing resources and their organization", "platform.html#pf_pftags", [
        [ "Platform organization tag : AS", "platform.html#pf_As", null ],
        [ "Computing resources: hosts, clusters and peers.", "platform.html#pf_Cr", [
          [ "host", "platform.html#pf_host", null ],
          [ "cluster", "platform.html#pf_cluster", null ],
          [ "peer", "platform.html#pf_peer", null ]
        ] ],
        [ "Network equipments: links and routers", "platform.html#pf_ne", [
          [ "router", "platform.html#pf_router", null ],
          [ "link", "platform.html#pf_link", null ]
        ] ],
        [ "Storage", "platform.html#pf_storage", [
          [ "Storage Main concepts", "platform.html#pf_sto_conc", null ],
          [ "storage_type", "platform.html#pf_sto_sttp", null ],
          [ "storage", "platform.html#pf_sto_st", null ],
          [ "mount", "platform.html#pf_sto_mo", null ],
          [ "mstorage", "platform.html#pf_sto_mst", null ]
        ] ]
      ] ],
      [ "Routing", "platform.html#pf_routing", [
        [ "Routing models", "platform.html#pf_rm", [
          [ "The router affair", "platform.html#pf_raf", null ],
          [ "Shortest-path based models", "platform.html#pf_rm_sh", null ],
          [ "Manually-entered route models", "platform.html#pf_rm_me", null ],
          [ "Simple/fast models", "platform.html#pf_rm_sf", null ]
        ] ],
        [ "Defining routes", "platform.html#ps_dec", [
          [ "link_ctn", "platform.html#pf_linkctn", null ],
          [ "ASroute", "platform.html#pf_asro", null ],
          [ "route", "platform.html#pf_ro", null ],
          [ "bypassRoute", "platform.html#pf_byro", null ]
        ] ],
        [ "Basic Routing Example", "platform.html#pb_baroex", null ]
      ] ],
      [ "Tags not (directly) describing the platform", "platform.html#pf_other_tags", [
        [ "config", "platform.html#pf_conf", null ],
        [ "random", "platform.html#pf_rand", null ],
        [ "include", "platform.html#pf_incl", null ],
        [ "trace and trace_connect", "platform.html#pf_tra", null ]
      ] ],
      [ "Hints and tips, or how to write a platform efficiently", "platform.html#pf_hints", [
        [ "AS Hierarchy", "platform.html#pf_as_h", null ],
        [ "Exit AS: why and how", "platform.html#pf_exit_as", null ],
        [ "P2P or how to use coordinates", "platform.html#pf_P2P_tags", null ],
        [ "Choosing wisely the routing model to use", "platform.html#pf_wisely", null ],
        [ "Hey, I want to describe a switch but there is no switch tag !", "platform.html#pf_switch", null ],
        [ "How to express multipath routing in platform files?", "platform.html#pf_platform_multipath", null ]
      ] ],
      [ "Bypassing the XML parser with your own C functions", "platform.html#pf_flexml_bypassing", null ]
    ] ],
    [ "Deployment Description", "deployment.html", [
      [ "Overview", "deployment.html#dep_over", null ],
      [ "An example", "deployment.html#dep_ex", null ],
      [ "Process", "deployment.html#process_tag", null ]
    ] ],
    [ "Tracing Simulations for Visualization", "tracing.html", [
      [ "How it works", "tracing.html#tracing_tracing_howitworks", null ],
      [ "Enabling using CMake", "tracing.html#tracing_tracing_enabling", null ],
      [ "Tracing categories functions", "tracing.html#instr_category_functions", null ],
      [ "Tracing marks functions", "tracing.html#instr_mark_functions", null ],
      [ "Tracing user variables functions", "tracing.html#instr_uservariables_functions", null ],
      [ "Tracing configuration Options", "tracing.html#tracing_tracing_options", null ],
      [ "Case studies", "tracing.html#tracing_tracing_example_parameters", null ],
      [ "Example of Instrumentation", "tracing.html#tracing_tracing_example", null ],
      [ "Analyzing the SimGrid Traces", "tracing.html#tracing_tracing_analyzing", null ]
    ] ],
    [ "Simgrid options and configurations", "options.html", [
      [ "Passing configuration options to the simulators", "options.html#options_using", null ],
      [ "Configuring the platform models", "options.html#options_model", [
        [ "Selecting the platform models", "options.html#options_model_select", null ],
        [ "Optimization level of the platform models", "options.html#options_model_optim", null ],
        [ "Numerical precision of the platform models", "options.html#options_model_precision", null ],
        [ "Parallel threads for model updates", "options.html#options_model_nthreads", null ],
        [ "Configuring the Network model", "options.html#options_model_network", [
          [ "Maximal TCP window size", "options.html#options_model_network_gamma", null ],
          [ "Corrective simulation factors", "options.html#options_model_network_coefs", null ],
          [ "Simulating cross-traffic", "options.html#options_model_network_crosstraffic", null ],
          [ "Coordinated-based network models", "options.html#options_model_network_coord", null ],
          [ "Simulating sender gap", "options.html#options_model_network_sendergap", null ],
          [ "Simulating asyncronous send", "options.html#options_model_network_asyncsend", null ],
          [ "Configuring packet-level pseudo-models", "options.html#options_pls", null ]
        ] ]
      ] ],
      [ "Configuring the Model-Checking", "options.html#options_modelchecking", [
        [ "Specifying a liveness property", "options.html#options_modelchecking_liveness", null ],
        [ "Going for stateful verification", "options.html#options_modelchecking_steps", null ],
        [ "Specifying the kind of reduction", "options.html#options_modelchecking_reduction", null ]
      ] ],
      [ "Configuring the User Process Virtualization", "options.html#options_virt", [
        [ "Selecting the virtualization factory", "options.html#options_virt_factory", null ],
        [ "Adapting the used stack size", "options.html#options_virt_stacksize", null ],
        [ "Running user code in parallel", "options.html#options_virt_parallel", null ]
      ] ],
      [ "Configuring the tracing subsystem", "options.html#options_tracing", null ],
      [ "Configuring SMPI", "options.html#options_smpi", [
        [ "Automatic benchmarking of SMPI code", "options.html#options_smpi_bench", null ],
        [ "Reporting simulation time", "options.html#options_smpi_timing", null ]
      ] ],
      [ "Configuring other aspects of SimGrid", "options.html#options_generic", [
        [ "XML file inclusion path", "options.html#options_generic_path", null ],
        [ "Behavior on Ctrl-C", "options.html#options_generic_exit", null ]
      ] ],
      [ "Logging Configuration", "options.html#options_log", null ],
      [ "Index of all existing configuration items", "options.html#options_index", null ]
    ] ],
    [ "Getting help", "help.html", null ]
];

==> simgrid_3.10.orig.tar.gz: SimGrid-3.10/doc/html/use.js <==
var use =
[
    [ "Using MSG", "use.html#using_msg", [
      [ "Basic examples and features", "use.html#MSG_ex_basics", [
        [ "Asynchronous communications", "use.html#MSG_ex_asynchronous_communications", [
          [ "Code of the application", "use.html#MSG_ext_icomms_code", null ],
          [ "Preliminary declarations", "use.html#MSG_ext_icomms_preliminary", null ],
          [ "Sender function", "use.html#MSG_ext_icomms_Sender", null ],
          [ "Receiver function", "use.html#MSG_ext_icomms_Receiver", null ],
          [ "Simulation core", "use.html#MSG_ext_icomms_core", null ],
          [ "Main function", "use.html#MSG_ext_icomms_Main", null ],
          [ "Waitall function for sender", "use.html#MSG_ext_icomms_fct_Waitall", null ],
          [ "Waitany function", "use.html#MSG_ext_icomms_fct_Waitany", null ],
          [ "From a sender", "use.html#MSG_ext_icomms_fct_Waitany_sender", null ],
          [ "From a receiver", "use.html#MSG_ext_icomms_fct_Waitany_receiver", null ]
        ] ],
        [ "Basic Master/Slaves", "use.html#MSG_ex_master_slave", [
          [ "Table of contents:", "use.html#MSG_ex_ms_TOC", null ],
          [ "Preliminary declarations", "use.html#MSG_ext_ms_preliminary", null ],
          [ "Master code", "use.html#MSG_ext_ms_master", null ],
          [ "Slave code", "use.html#MSG_ext_ms_slave", null ],
          [ "Forwarder code", "use.html#MSG_ext_ms_forwarder", null ],
          [ "Simulation core", "use.html#MSG_ext_ms_core", null ],
          [ "Main() function", "use.html#MSG_ext_ms_main", null ]
        ] ],
        [ "Helping files", "use.html#MSG_ext_ms_helping", [
          [ "Example of application file", "use.html#MSG_ext_ms_application", null ],
          [ "Example of platform file", "use.html#MSG_ext_ms_platform", null ]
        ] ]
      ] ]
    ] ],
    [ "Using SMPI", "use.html#using_smpi", null ],
    [ "Using Model Checking", "use.html#using_MC", null ],
    [ "Using Trace", "use.html#using_trace", null ],
    [ "Using SimDag", "use.html#using_simdag", null ],
    [ "Using SIMIX", "use.html#using_simix", null ],
    [ "Platform Description", "platform.html", [
      [ "Some words about XML and DTD", "platform.html#pf_overview", null ],
      [ "Basic concepts", "platform.html#pf_basics", null ],
      [ "Describing resources and their organization", "platform.html#pf_pftags", [
        [ "Platform organization tag : AS", "platform.html#pf_As", null ],
        [ "Computing resources: hosts, clusters and peers.", "platform.html#pf_Cr", [
          [ "host", "platform.html#pf_host", null ],
          [ "cluster", "platform.html#pf_cluster", null ],
          [ "peer", "platform.html#pf_peer", null ]
        ] ],
        [ "Network equipments: links and routers", "platform.html#pf_ne", [
          [ "router", "platform.html#pf_router", null ],
          [ "link", "platform.html#pf_link", null ]
        ] ],
        [ "Storage", "platform.html#pf_storage", [
          [ "Storage Main concepts", "platform.html#pf_sto_conc", null ],
          [ "storage_type", "platform.html#pf_sto_sttp", null ],
          [ "storage", "platform.html#pf_sto_st", null ],
          [ "mount", "platform.html#pf_sto_mo", null ],
          [ "mstorage", "platform.html#pf_sto_mst", null ]
        ] ]
      ] ],
      [ "Routing", "platform.html#pf_routing", [
        [ "Routing models", "platform.html#pf_rm", [
          [ "The router affair", "platform.html#pf_raf", null ],
          [ "Shortest-path based models", "platform.html#pf_rm_sh", null ],
          [ "Manually-entered route models", "platform.html#pf_rm_me", null ],
          [ "Simple/fast models", "platform.html#pf_rm_sf", null ]
        ] ],
        [ "Defining routes", "platform.html#ps_dec", [
          [ "link_ctn", "platform.html#pf_linkctn", null ],
          [ "ASroute", "platform.html#pf_asro", null ],
          [ "route", "platform.html#pf_ro", null ],
          [ "bypassRoute", "platform.html#pf_byro", null ]
        ] ],
        [ "Basic Routing Example", "platform.html#pb_baroex", null ]
      ] ],
      [ "Tags not (directly) describing the platform", "platform.html#pf_other_tags", [
        [ "config", "platform.html#pf_conf", null ],
        [ "random", "platform.html#pf_rand", null ],
        [ "include", "platform.html#pf_incl", null ],
        [ "trace and trace_connect", "platform.html#pf_tra", null ]
      ] ],
      [ "Hints and tips, or how to write a platform efficiently", "platform.html#pf_hints", [
        [ "AS Hierarchy", "platform.html#pf_as_h", null ],
        [ "Exit AS: why and how", "platform.html#pf_exit_as", null ],
        [ "P2P or how to use coordinates", "platform.html#pf_P2P_tags", null ],
        [ "Choosing wisely the routing model to use", "platform.html#pf_wisely", null ],
        [ "Hey, I want to describe a switch but there is no switch tag !", "platform.html#pf_switch", null ],
        [ "How to express multipath routing in platform files?", "platform.html#pf_platform_multipath", null ]
      ] ],
      [ "Bypassing the XML parser with your own C functions", "platform.html#pf_flexml_bypassing", null ]
    ] ],
    [ "Deployment Description", "deployment.html", [
      [ "Overview", "deployment.html#dep_over", null ],
      [ "An example", "deployment.html#dep_ex", null ],
      [ "Process", "deployment.html#process_tag", null ]
    ] ],
    [ "Tracing Simulations", "tracing.html", [
      [ "Enabling using CMake", "tracing.html#tracing_tracing_enabling", null ],
      [ "Tracing categories functions", "tracing.html#instr_category_functions", null ],
      [ "Tracing marks functions", "tracing.html#instr_mark_functions", null ],
      [ "Tracing user variables functions", "tracing.html#instr_uservariables_functions", null ],
      [ "Tracing configuration Options", "tracing.html#tracing_tracing_options", null ],
      [ "Case studies", "tracing.html#tracing_tracing_example_parameters", null ],
      [ "Example of Instrumentation", "tracing.html#tracing_tracing_example", null ],
      [ "Analyzing SimGrid Simulation Traces", "tracing.html#tracing_tracing_analyzing", [
        [ "Viva Visualization Tool", "tracing.html#tracing_viva_analysis", [
          [ "Time Slice", "tracing.html#tracing_viva_time_slice", null ],
          [ "Hierarchical Graph View", "tracing.html#tracing_viva_graph", null ],
          [ "Basic Graph Configuration", "tracing.html#basic_conf", null ],
          [ "Customizing the Graph Representation", "tracing.html#custom_graph", null ]
        ] ]
      ] ]
    ] ],
    [ "Simgrid options and configurations", "options.html", [
      [ "Passing configuration options to the simulators", "options.html#options_using", null ],
      [ "Configuring the platform models", "options.html#options_model", [
        [ "Selecting the platform models", "options.html#options_model_select", null ],
        [ "Optimization level of the platform models", "options.html#options_model_optim", null ],
        [ "Numerical precision of the platform models", "options.html#options_model_precision", null ],
        [ "Parallel threads for model updates", "options.html#options_model_nthreads", null ],
        [ "Configuring the Network model", "options.html#options_model_network", [
          [ "Maximal TCP window size", "options.html#options_model_network_gamma", null ],
          [ "Corrective simulation factors", "options.html#options_model_network_coefs", null ],
          [ "Simulating cross-traffic", "options.html#options_model_network_crosstraffic", null ],
          [ "Coordinated-based network models", "options.html#options_model_network_coord", null ],
          [ "Simulating sender gap", "options.html#options_model_network_sendergap", null ],
          [ "Simulating asyncronous send", "options.html#options_model_network_asyncsend", null ],
          [ "Configuring packet-level pseudo-models", "options.html#options_pls", null ]
        ] ]
      ] ],
      [ "Configuring the Model-Checking", "options.html#options_modelchecking", [
        [ "Specifying a liveness property", "options.html#options_modelchecking_liveness", null ],
        [ "Going for stateful verification", "options.html#options_modelchecking_steps", null ],
        [ "Specifying the kind of reduction", "options.html#options_modelchecking_reduction", null ]
      ] ],
      [ "Configuring the User Process Virtualization", "options.html#options_virt", [
        [ "Selecting the virtualization factory", "options.html#options_virt_factory", null ],
        [ "Adapting the used stack size", "options.html#options_virt_stacksize", null ],
        [ "Running user code in parallel", "options.html#options_virt_parallel", null ]
      ] ],
      [ "Configuring the tracing subsystem", "options.html#options_tracing", null ],
      [ "Configuring SMPI", "options.html#options_smpi", [
        [ "Automatic benchmarking of SMPI code", "options.html#options_smpi_bench", null ],
        [ "Reporting simulation time", "options.html#options_smpi_timing", null ],
        [ "Simulating MPI detached send", "options.html#options_model_smpi_detached", null ],
        [ "Simulating MPI collective algorithms", "options.html#options_model_smpi_collectives", null ]
      ] ],
      [ "Configuring other aspects of SimGrid", "options.html#options_generic", [
        [ "XML file inclusion path", "options.html#options_generic_path", null ],
        [ "Behavior on Ctrl-C", "options.html#options_generic_exit", null ]
      ] ],
      [ "Logging Configuration", "options.html#options_log", null ],
      [ "Index of all existing configuration items", "options.html#options_index", null ]
    ] ],
    [ "Getting help", "help.html", null ]
];
